<div align="center">
  <img src="docs/static/icon_proposal.svg" alt="icon_proposal.csv" height="150px">
</div>

<br>
<br>

<div align="center">
  <p>This is gempipe, a tool for the reconstruction of strain-specific genome-scale metabolic models.</p>
</div>

<h1 align="center">
    <a href="https://gempipe.readthedocs.io/en/latest/">Documentation 📖</a>
</h1>

## How to cite ✍🏼

TODO
